@@ -39,6 +39,7 @@ import mobac.program.model.EastNorthCoordinate;
 import mobac.program.model.MapSelection;
 import mobac.program.model.MercatorPixelCoordinate;
 import mobac.program.model.Settings;
+import mobac.utilities.I18nUtils;
 import mobac.utilities.MyMath;
 
 import org.apache.log4j.Logger;
@@ -198,7 +199,7 @@ public class PreviewMap extends JMapViewer {
 	protected void paintComponent(Graphics graphics) {
 		if (!isEnabled()) {
 			graphics.setFont(LOADING_FONT);
-			graphics.drawString("Please wait - loading map data", 100, 100);
+			graphics.drawString(I18nUtils.localizedStringForKey("map_loading_wait"), 100, 100);
 			return;
 		}
 		if (mapSource == null)
@@ -324,8 +325,6 @@ public class PreviewMap extends JMapViewer {
 	 * @param notifyListeners
 	 */
 	public void setSelectionAndZoomTo(MapSelection ms, boolean notifyListeners) {
-		if (!ms.isAreaSelected())
-			return;
 		log.trace("Setting selection to: " + ms);
 		Point max = ms.getBottomRightPixelCoordinate(MAX_ZOOM);
 		Point min = ms.getTopLeftPixelCoordinate(MAX_ZOOM);
