@@ -26,6 +26,7 @@ import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlElementWrapper;
 import javax.xml.bind.annotation.XmlElements;
+import javax.xml.bind.annotation.XmlList;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlSeeAlso;
 import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
@@ -50,9 +51,13 @@ public class CustomMultiLayerMapSource extends AbstractMultiLayerMapSource {
 			@XmlElement(name = "cloudMade", type = CustomCloudMade.class),
 			@XmlElement(name = "localTileSQLite", type = CustomLocalTileSQliteMapSource.class),
 			@XmlElement(name = "localTileFiles", type = CustomLocalTileFilesMapSource.class),
-			@XmlElement(name = "localTileZip", type = CustomLocalTileZipMapSource.class) })
+			@XmlElement(name = "localTileZip", type = CustomLocalTileZipMapSource.class),
+			@XmlElement(name = "localImageFile", type = CustomLocalImageFileMapSource.class)})
 	protected List<CustomMapSource> layers = new ArrayList<CustomMapSource>();
 
+	@XmlList()
+	protected List<Float> layersAlpha = new ArrayList<Float>();
+
 	@XmlElement(defaultValue = "#000000")
 	@XmlJavaTypeAdapter(ColorAdapter.class)
 	protected Color backgroundColor = Color.BLACK;
@@ -90,6 +95,14 @@ public class CustomMultiLayerMapSource extends AbstractMultiLayerMapSource {
 		return backgroundColor;
 	}
 
+	@Override
+	protected float getLayerAlpha(int layerIndex) {
+		if (layersAlpha.size() <= layerIndex)
+			return 1.0f;
+
+		return layersAlpha.get(layerIndex);
+	}
+
 	// public static void main(String[] args) {
 	// OutputStream os = null;
 	// try {
