@@ -16,6 +16,8 @@
  ******************************************************************************/
 package mobac.program.atlascreators;
 
+import mobac.program.annotations.AtlasCreatorName;
+
 
 /**
  * Creates maps using the AndNav atlas format.
@@ -24,6 +26,7 @@ package mobac.program.atlascreators;
  * uses a separate directory for each used map source and inside one directory
  * for each zoom level.
  */
+@AtlasCreatorName("AndNav atlas format")
 public class AndNav extends OSMTracker {
 
 	public AndNav() {
