@@ -16,11 +16,14 @@
  ******************************************************************************/
 package mobac.program.atlascreators;
 
+import mobac.program.annotations.AtlasCreatorName;
+
 /**
  * Creates maps using the <a
  * href="http://www.codesector.com/maverick.php">Maverick</a> atlas format
  * (Android application).
  */
+@AtlasCreatorName("Maverick atlas format")
 public class Maverick extends OSMTracker {
 
 	public Maverick() {
