@@ -57,8 +57,6 @@ public class OruxMapsSqlite extends OruxMaps implements RequiresSQLite {
 
 	private StringBuilder otrk2MapsContent;
 
-	private int customTileCount;
-
 	public OruxMapsSqlite() {
 		super();
 		SQLiteLoader.loadSQLiteOrShowError();
@@ -77,7 +75,7 @@ public class OruxMapsSqlite extends OruxMaps implements RequiresSQLite {
 		try {
 			SQLiteLoader.loadSQLite();
 		} catch (SQLException e) {
-			throw new AtlasTestException(SQLiteLoader.MSG_SQLITE_MISSING, e);
+			throw new AtlasTestException(SQLiteLoader.getMsgSqliteMissing(), e);
 		}
 	}
 
@@ -145,11 +143,15 @@ public class OruxMapsSqlite extends OruxMaps implements RequiresSQLite {
 		CacheTileProvider ctp = new CacheTileProvider(mapDlTileProvider);
 		try {
 			mapDlTileProvider = ctp;
-			OruxMapTileBuilder mapTileBuilder = new OruxMapTileBuilder(this, new OruxMapTileWriterDB());
-			customTileCount = mapTileBuilder.getCustomTileCount();
+			MapTileWriter mtw = new OruxMapTileWriterDB();
+			OruxMapTileBuilder mapTileBuilder = new OruxMapTileBuilder(this, mtw);
+			//customTileCount = mapTileBuilder.getCustomTileCount();
 			atlasProgress.initMapCreation(mapTileBuilder.getCustomTileCount());
 			mapTileBuilder.createTiles();
-		} finally {
+			mtw.finalizeMap();
+		} catch(IOException e){
+			throw new MapCreationException(map, e);
+		}finally {
 			ctp.cleanup();
 		}
 	}
@@ -177,7 +179,7 @@ public class OruxMapsSqlite extends OruxMaps implements RequiresSQLite {
 				long heapAvailable = r.maxMemory() - r.totalMemory() + r.freeMemory();
 
 				tileCounter++;
-				if (heapAvailable < HEAP_MIN || tileCounter > MAX_BATCH_SIZE || tileCounter == customTileCount) {
+				if (heapAvailable < HEAP_MIN || tileCounter > MAX_BATCH_SIZE) {
 					commit();
 				}
 			} catch (SQLException e) {
